@@ -22,7 +22,7 @@ from datamodel.fields import Field
 from datamodel.types import JSON_TYPES
 from datamodel.converters import parse_type
 from datamodel.validation import validator
-from datamodel.exceptions import ValidationError
+from datamodel import exceptions
 from .parsers.encoders import DefaultEncoder
 
 
@@ -181,6 +181,7 @@ class ModelMeta(type):
             cls.__frozen__ = False
         # Initialized Data Model = True
         cls.__initialised__ = True
+        cls.__errors__ = None
         super(ModelMeta, cls).__init__(*args, **kwargs)
 
 
@@ -395,17 +396,19 @@ class BaseModel(metaclass=ModelMeta):
                     errors[name] = error
         if errors:
             if self.Meta.strict is True:
-
-                raise ValidationError(
-                    message="""There are errors in your data.
-                    Hint: please check the "payload" attribute in the exception.""",
+                raise exceptions.ValidationError(
+                    message=f"""{self.modelName}: There are errors in your data.
+ Hint: please check the "payload" attribute in the exception.""",
                     payload=errors
                 )
-            print(errors)
+            self.__errors__ = errors
             object.__setattr__(self, "__valid__", False)
         else:
             object.__setattr__(self, "__valid__", True)
 
+    def get_errors(self):
+        return self.__errors__
+
     @classmethod
     def make_model(cls, name: str, schema: str = "public", fields: list = None):
         parent = inspect.getmro(cls)
